| /freebsd/contrib/llvm-project/llvm/include/llvm/Support/ |
| H A D | DebugCounter.h | 108 auto &Us = instance(); in getCounterState() local 109 auto Result = Us.Counters.find(ID); in getCounterState() 110 assert(Result != Us.Counters.end() && "Asking about a non-set counter"); in getCounterState() 116 auto &Us = instance(); in setCounterState() local 117 auto &Counter = Us.Counters[ID]; in setCounterState()
|
| /freebsd/contrib/llvm-project/llvm/lib/Support/ |
| H A D | DebugCounter.cpp | 212 auto &Us = instance(); in print() local 216 const CounterInfo &C = Us.Counters[CounterID]; in print() 225 auto &Us = instance(); in shouldExecuteImpl() local 226 auto Result = Us.Counters.find(CounterName); in shouldExecuteImpl() 227 if (Result != Us.Counters.end()) { in shouldExecuteImpl() 238 if (Us.BreakOnLast && CurrIdx == (CounterInfo.Chunks.size() - 1) && in shouldExecuteImpl()
|
| /freebsd/contrib/llvm-project/llvm/lib/IR/ |
| H A D | User.cpp | 133 void *User::allocateFixedOperandUser(size_t Size, unsigned Us, in allocateFixedOperandUser() argument 135 assert(Us < (1u << NumUserOperandsBits) && "Too many operands"); in allocateFixedOperandUser() 145 ::operator new(Size + sizeof(Use) * Us + DescBytesToAllocate)); in allocateFixedOperandUser() 147 Use *End = Start + Us; in allocateFixedOperandUser() 149 Obj->NumUserOperands = Us; in allocateFixedOperandUser()
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/Hexagon/ |
| H A D | HexagonCommonGEP.cpp | 286 const UseSet &Us = I.second; in operator <<() local 287 OS << I.first << " -> #" << Us.size() << '{'; in operator <<() 288 for (const Use *U : Us) { in operator <<() 360 UseSet Us; in processGepInst() local 370 Us.insert(&UI.getUse()); in processGepInst() 394 if (!Us.empty()) { in processGepInst() 396 Uses[PN].insert_range(Us); in processGepInst() 758 UseSet &Us = UF->second; in recalculatePlacement() local 759 for (Use *U : Us) { in recalculatePlacement() 966 UseSet &Us = UF->second; in separateChainForNode() local [all …]
|
| H A D | HexagonGenInsert.cpp | 1324 RegisterSet Us; in selectCandidates() local 1326 getInstrUses(DefI, Us); in selectCandidates() 1331 for (unsigned R = Us.find_first(); R; R = Us.find_next(R)) { in selectCandidates() 1340 for (unsigned R = Us.find_first(); R; R = Us.find_next(R)) { in selectCandidates()
|
| /freebsd/contrib/llvm-project/lldb/source/Plugins/ScriptInterpreter/Python/ |
| H A D | ScriptedPythonInterface.h | |
| /freebsd/contrib/llvm-project/clang/include/clang/Basic/ |
| H A D | arm_sme.td | 357 …defm SVUMOP4A_HtoD : MOP4<"a", "_za64", "Us", "aarch64_sme_umop4a_za64_wide", [ImmCheck<0, ImmChe… 358 …defm SVUMOP4S_HtoD : MOP4<"s", "_za64", "Us", "aarch64_sme_umop4s_za64_wide", [ImmCheck<0, ImmChe… 414 defm SVUSMOP4A_D : USMOP4<"a", "_za64", "Us", "_za64", [ImmCheck<0, ImmCheck0_7>]>; 415 defm SVUSMOP4S_D : USMOP4<"s", "_za64", "Us", "_za64", [ImmCheck<0, ImmCheck0_7>]>; 507 …def SVUSMOPA : Inst<"svmopa_za32[_{d}]_m", "viPPdd", "Us", MergeNone, "aarch64_sme_umopa_za32", [I… 510 …def SVUSMOPS : Inst<"svmops_za32[_{d}]_m", "viPPdd", "Us", MergeNone, "aarch64_sme_umops_za32", [I… 519 …def SVVDOT_LANE_ZA32_VG1x2_U : Inst<"svvdot_lane_za32[_{d}]_vg1x2", "vm2di", "Us", MergeNone, "aar… 567 …def SVVDOT_LANE_ZA64_VG1x4_U : Inst<"svvdot_lane_za64[_{d}]_vg1x4", "vm4di", "Us", MergeNone, "aar… 571 …def SVDOT_MULTI_ZA64_VG1x2_U16 : Inst<"svdot_za64[_{d}]_vg1x2", "vm22", "Us", MergeNone, "aarch64… 572 …def SVDOT_MULTI_ZA64_VG1x4_U16 : Inst<"svdot_za64[_{d}]_vg1x4", "vm44", "Us", MergeNone, "aarch64… [all …]
|
| H A D | BuiltinsAMDGPU.def | 41 BUILTIN(__builtin_amdgcn_workgroup_size_x, "Us", "nc") 42 BUILTIN(__builtin_amdgcn_workgroup_size_y, "Us", "nc") 43 BUILTIN(__builtin_amdgcn_workgroup_size_z, "Us", "nc")
|
| H A D | arm_sve_sme_incl.td | 31 // An example typespec is "Us" - unsigned short - svuint16_t. The available
|
| H A D | arm_sve.td | 906 defm SVFCVTZU_U16_F16 : SInstCvtMXZ<"svcvt_u16[_f16]", "ddPO", "dPO", "Us", "aarch64_sve_fcvtzu", [… 932 defm SVFCVTZU_F16_U16 : SInstCvtMXZ<"svcvt_f16[_u16]", "OOPd", "OPd", "Us", "aarch64_sve_ucvtf", [I… 1131 def UnsignedHalf : sat_type<"U", "Us">;
|
| /freebsd/crypto/openssl/apps/ |
| H A D | dsa1024.pem | 3 mUd6UvuF5NmmezibaIqEm4fGHrV+hktTW1nPcWUZiG7OZq5riDb77Cjcwtelu+Us
|
| /freebsd/contrib/llvm-project/lldb/source/Plugins/ScriptInterpreter/Python/Interfaces/ |
| H A D | ScriptedPythonInterface.h | 503 template <std::size_t... I, typename... Ts, typename... Us> 505 std::tuple<Us...> &transformed_args, in ReassignPtrsOrRefsArgs() 514 template <typename... Ts, typename... Us> 516 std::tuple<Us...> &transformed_args) { in ReassignPtrsOrRefsArgs() 517 if (sizeof...(Ts) != sizeof...(Us)) in ReassignPtrsOrRefsArgs()
|
| /freebsd/crypto/openssh/regress/unittests/sshkey/testdata/ |
| H A D | rsa_2 | 23 Le6nSGVKG4whqrAz3EsbKUA8kiLldbgFNjl+ryjmidnjZEpKRxmQ0XZuu/4k6+Us
|
| /freebsd/contrib/llvm-project/compiler-rt/lib/xray/ |
| H A D | xray_allocator.h | 139 T *initArray(size_t N, U &&... Us) XRAY_NEVER_INSTRUMENT { in initArray() argument 143 new (A + (--N)) T(std::forward<U>(Us)...); in initArray()
|
| /freebsd/contrib/llvm-project/llvm/include/llvm/IR/ |
| H A D | InlineAsm.h | 258 Us, enumerator 500 case ConstraintCode::Us: in getMemConstraintName()
|
| /freebsd/contrib/llvm-project/llvm/include/llvm/ADT/ |
| H A D | STLExtras.h | 137 template <typename T, typename... Us> struct TypesAreDistinct; 138 template <typename T, typename... Us> 140 : std::integral_constant<bool, !is_one_of<T, Us...>::value && 141 TypesAreDistinct<Us...>::value> {}; 168 template <typename T, typename... Us> struct FirstIndexOfType; 169 template <typename T, typename U, typename... Us> 170 struct FirstIndexOfType<T, U, Us...> 171 : std::integral_constant<size_t, 1 + FirstIndexOfType<T, Us...>::value> {}; 172 template <typename T, typename... Us> 173 struct FirstIndexOfType<T, T, Us...> : std::integral_constant<size_t, 0> {};
|
| /freebsd/contrib/llvm-project/llvm/lib/Analysis/ |
| H A D | MemoryDependenceAnalysis.cpp | 301 for (const Use &Us : LoadOperand->uses()) { in getInvariantGroupPointerDependency() local 302 auto *U = dyn_cast<Instruction>(Us.getUser()); in getInvariantGroupPointerDependency()
|
| H A D | MemorySSA.cpp | 2510 for (const User *Us : PointerOperand->users()) { in getInvariantGroupClobberingInstruction() local 2511 auto *U = dyn_cast<Instruction>(Us); in getInvariantGroupClobberingInstruction()
|
| /freebsd/contrib/llvm-project/llvm/lib/Target/ARM/ |
| H A D | ARMTargetTransformInfo.cpp | 1707 const User *Us = *I->users().begin(); in getGatherScatterOpCost() local 1708 if (isa<ZExtInst>(Us) || isa<SExtInst>(Us)) { in getGatherScatterOpCost() 1711 cast<Instruction>(Us)->getType()->getScalarSizeInBits(); in getGatherScatterOpCost()
|
| H A D | ARMISelLowering.h | 576 return InlineAsm::ConstraintCode::Us; in getInlineAsmMemConstraint()
|
| H A D | ARMISelDAGToDAG.cpp | 5861 case InlineAsm::ConstraintCode::Us: in SelectInlineAsmMemoryOperand()
|
| /freebsd/contrib/tzdata/ |
| H A D | asia | 2855 # the capital of the Hovd province is sometimes called Hovd, sometimes Dund-Us, 2996 # Hovd, a.k.a. Chovd, Dund-Us, Dzhargalant, Khovd, Jirgalanta
|
| /freebsd/share/termcap/ |
| H A D | termcap | 502 :Us=q:Uv=x:Ux=k:Uw=j:Uz=m:Uy=l:Uu=n:Uq=w:Up=v:Ut=t:Ur=u:\ 514 :Us=q:Uv=x:Ux=k:Uw=j:Uz=m:Uy=l:Uu=n:Uq=w:Up=v:Ut=t:Ur=u:\
|